pygeodesy.mgrs.Mgrs4Tuple

Package pygeodesy :: Module mgrs :: Class Mgrs4Tuple |
[frames] | no frames]

# Class Mgrs4Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Mgrs4Tuple

4-Tuple `(zone, EN, easting, northing)`, `zone` and grid tile `EN` as `str`, `easting` and `northing` in `meter`.

Note: The `zone` consists of either the longitudinal zone number plus the latitudinal band letter or only the polar region letter.

Instance Methods
toMgrs(self, **Mgrs_and_kwds) Return this Mgrs4Tuple as an Mgrs instance. |
to6Tuple(self, band='', datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`) Extend this Mgrs4Tuple to a Mgrs6Tuple. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
| digraph DEPRECATED, use attribute `EN`.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### to6Tuple (self, band='', datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`) |
Extend this Mgrs4Tuple to a Mgrs6Tuple. Arguments: `band` - The band (`str`). `datum` - The datum (Datum). Returns: An Mgrs6Tuple`(zone, EN, easting, northing, band, datum)`.

Property Details

### digraph DEPRECATED, use attribute `EN`. Get method: digraph(self) - DEPRECATED, use attribute `EN`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.